@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20140328';
+our $VERSION = '0.20140430';
 
-# Table last modified: 2014-03-28
+# Table last modified: 2014-04-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,20 +103,20 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:4(?:7[05-7]|8[13]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[14-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '101' => '(?:8(?:5(?:6[0-2568]|8[1568]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568]|1[0-24579])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:41|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:30|77|8[0-35]|2[4-6]|0[58]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|6[67]|5[24-68]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|3(?:7[027-9]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|0[1-579]|3[02358]|4[0-5])|5(?:1[028]|3[0135689]|5[013-689]|7[02]|6[036-8]|4[03468]|2[0136-8]|0[1256]|8[014578])|2(?:40|1[0-258]|7[17]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|0[257-9]|8[0-57-9]|7[4-9]|5[03-8]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|6050|7444))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|7[014-8]|8[0139]|4[25]|6[1-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|3(?:7[027-9]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|0[1-579]|3[02358]|4[0-5])|5(?:1[028]|3[0135689]|5[013-689]|7[02]|6[036-8]|4[03468]|2[0136-8]|0[1256]|8[014578])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|5[0-35-7]|6[026]|8[0-24589])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|0[1-3578]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|0[257-9]|8[0-57-9]|7[4-9]|5[03-8]|3[0457])|6(?:54|6[0568]|3[0149]|2[136]|1[013-58]|8[035-9]|7[078]|4[024]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:1[0-35]|2[02]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|6050|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|8[24]|1[0-246-9]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
+    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|8[24]|1[0-246-9]|4[08]|6[06-8])|3(?:55|60|4[028]|7[013]|2[0346]|8[048]|3[026])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[3-57]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
-    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
+    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[0379]|2[014-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-246]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
@@ -130,20 +130,20 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-37]|0[17]|1[0178])|1(?:81|1[0-35])|2(?:10|22)|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|1(?:45|81|1[0-35])|2(?:10|22)|080))',
     '136' => '(?:8(?:5(?:4[03]|8[01589]|1[2357]|3[13]|7[057]|6[07]|5[05]|0[1257]|2[1-35])|6(?:[68]6|3[057]|7[0157]|2[0267]|4[08]|1[125]|0[3578])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|2[13569]|6[0367]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|2[13568]|3[01479]|8[0278]|1[14-79]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[017-9]|2[01379]|4[02-46-8]|0[2-6]|8[048]|6[03-5]|7[1-39]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)))',
     '143' => '(?:85(?:28|70|5[02578]|3[13589]|0[24578]|8[05]|6[0578]|4[014]|1[145]))',
-    '144' => '(?:8(?:5(?:44|5[015]|8[018]|3[0-356]|7[057]|2[25]|1[01356]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
+    '144' => '(?:8(?:5(?:44|5[015]|8[018]|3[0-356]|7[057]|2[25]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[01])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|5[158]|8[058]|1[0-25]|7[67]|0[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
     '150' => '(?:8(?:5(?:45|5[0-35]|6[37]|2[25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
-    '153' => '(?:8(?:5(?:6[05-7]|7[1378]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
+    '153' => '(?:8(?:5(?:6[05-7]|7[1378]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|1[02568]|0[1-689])|6(?:[12]0|01|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|6[05-8]|2[0135]|3[0-369]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:22|33|55|88|0[246]|1[01])|666))',
@@ -152,8 +152,8 @@ our %ZIP_TABLE = (
     '160' => '(?:8(?:3(?:41|89|3[01468]|0[14689]|1[169]|6[168]|2[147]|5[18]|7[457])|5(?:01|65|1[0-259]|4[379]|2[0-249]|3[05]|7[157]|8[0-36-9])|4(?:50|72|1[015]|2[0239]|4[47]|3[013]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|2[0-258]|6[057]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[02468]|5[045]|6[689]|3[68]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[157])|0(?:22|55|0[15])|953))',
-    '163' => '(?:(?:0(?:5(?:7[056]|5[7-9]|6[069])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|9(?:43|3[89])|4(?:56|78)|2[67]8|7[27]7)|1(?:3(?:50|71|6[38]|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|8[08])|5(?:88|3[37]))|8(?:6(?:02|26|80|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[67]7|30|41|2[25]|8[58]|5[05]|0[13-5]|1[12])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[24])|7(?:01|25)))',
+    '163' => '(?:(?:0(?:5(?:7[056]|5[7-9]|6[069])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|9(?:43|3[89])|4(?:56|78)|2[67]8|7[27]7)|1(?:3(?:50|71|6[38]|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|26|80|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
+    '164' => '(?:8(?:5(?:[67]7|30|2[25]|8[58]|5[05]|0[13-5]|1[12]|4[01])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[24])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:85(?:20|88|3[13589]|6[5-7]|4[025]|0[1-36]|7[078]))',
     '167' => '(?:8(?:5(?:[246]0|34|85|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
@@ -180,7 +180,7 @@ our %ZIP_TABLE = (
     '189' => '(?:85(?:[01]1|20|85|5[05]))',
     '190' => '(?:(?:8(?:5(?:2[028]|3[015-79]|5[013-578]|0[135-8]|6[0-256]|8[1-3689]|7[1-358]|1[013-9]|4[034])|6(?:09|66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|0[1-35-79]|1[0-2])|6(?:60|86)))',
-    '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-7])))',
+    '192' => '(?:(?:8(?:5(?:77|85|2[025]|5[01368]|6[28]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-7])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
     '194' => '(?:(?:8(?:5(?:77|1[015]|4[03]|0[23578]|8[0568]|5[0158]|2[07]|6[067]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
     '195' => '(?:85(?:85|5[05]))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:36|58|77|1[015]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:20|53|78|0[149]|1[1-6]|6[08]|8[046])|7(?:11|22|65)|080|173))',
+    '220' => '(?:8(?:5(?:36|58|77|1[015]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|0[149]|2[03]|1[1-6]|6[08]|8[046])|7(?:11|22|65)|080|173))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|2[023]|5[08])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:[58][058]|1[0-25]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
@@ -239,7 +239,7 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|392)|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
-    '260' => '(?:8(?:6(?:0[13467]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7]|1[02389])|5(?:40|7[0257]|2[134]|8[0568]|0[1-9]|3[4-68]|5[1457-9]|6[0-467]|1[0-3568])|7(?:3[03]|1[02357]|0[137]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7]|1[02389])|5(?:40|7[0257]|8[0568]|0[1-9]|3[4-68]|5[1457-9]|6[0-467]|2[13478]|1[0-3568])|7(?:3[03]|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[0235]|0[1-478]|2[0-2]|8[125-8])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-2])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
@@ -294,12 +294,12 @@ our %ZIP_TABLE = (
     '318' => '(?:85[01]1)',
     '319' => '(?:(?:1(?:1(?:9[24-6]|8[48])|29[235]|59[23]|393)|0(?:29[2-5]|39[3-57]|19[28])|2692|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|8[058]|4[013]|7[07]|0[1-3578]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
-    '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
+    '321' => '(?:(?:3(?:29[235-8]|49[378]|59[578]|39[25])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86))|[01]192))',
-    '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
+    '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|86|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
-    '326' => '(?:(?:8(?:5(?:11|20|72|85|5[08]|0[125])|6(?:[01]1|30|86))|039[25]))',
+    '326' => '(?:(?:8(?:5(?:11|72|85|5[08]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:59[568]|49[28]|69[26]|195)|1(?:19[3-68]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[23]|392)|3292))',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-4])|1(?:19[23]|292)))',
-    '350' => '(?:(?:0(?:2(?:9[25]|8[03-9])|39[2-6]|49[3-6]|19[237])|1(?:1(?:9[24-8]|8[18])|3(?:9[28]|8[08])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[0178])))',
+    '350' => '(?:(?:0(?:2(?:9[25]|8[03-9])|39[2-6]|49[3-6]|19[237])|1(?:1(?:9[24-8]|8[18])|3(?:9[28]|8[08])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[017])))',
     '351' => '(?:(?:8(?:5(?:[26]0|0[18]|5[15]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -364,7 +364,7 @@ our %ZIP_TABLE = (
     '388' => '(?:85(?:11|22|55))',
     '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[24-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
     '390' => '(?:(?:8(?:5(?:0[1-35-8]|4[013]|1[0158]|3[01359]|5[05]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
-    '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[07]|1[0-2]|8[08]|2[15])|0(?:29[2-6]|39[2-6]|192)))',
+    '391' => '(?:(?:85(?:31|40|0[13]|5[058]|1[0-2]|8[08]|2[15]|6[017])|0(?:29[2-6]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:11|85|0[1-3])|601))',
     '394' => '(?:8(?:5(?:[24]0|77|1[0-25]|8[58]|5[05])|6(?:11|65|86)))',
@@ -426,12 +426,12 @@ our %ZIP_TABLE = (
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[124]))',
     '453' => '(?:8(?:5(?:40|55|77|8[015]|3[39]|1[0-258]|6[57]|2[12]|0[15])|6(?:[01]1|62|86)|7(?:58|65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
-    '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[01458]5|21|3[05])))',
-    '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
+    '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[01458]5|3[05]|2[15])))',
+    '456' => '(?:8(?:5(?:23|30|5[5-7]|6[07]|1[16]|8[0578]|0[12])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:[48]5|22|77|3[0-35]|5[158]|1[0-25]|6[067]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
-    '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|3[0-35-8]|0[1-3568]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-59]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|4[0135]|7[04578]|0[13-9]|1[0-8]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
+    '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|3[0-35-8]|0[1-3568]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-59]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|4[0135]|7[04578]|0[13-9]|1[0-8]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|91|1[18]|0[1346-8])|20[1-4]))',
     '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666|739))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
@@ -472,14 +472,14 @@ our %ZIP_TABLE = (
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|1[015-8]|3[0-479]|5[0-5]|0[1-378]|2[0-257-9])))',
     '501' => '(?:(?:0(?:49[2-8]|69[2-7]|29[2-6]|[135]92|79[78])|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|4(?:29[278]|19[23]|59[25])|1(?:19[2-68]|[235]92)|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[0-2]1|58|67)|792))',
-    '503' => '(?:(?:8(?:5(?:5[02-46-9]|1\d|2[0-3]|0[1-9]|7[01]|6[0-24-9])|60[134])|0(?:19[258]|29[256]|[46]95|392)|2(?:39[2-7]|49[2-5]|19[23])|1(?:39[2-6]|59[235])))',
+    '503' => '(?:(?:8(?:5(?:5[02-46-9]|1\d|2[0-3]|0[1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[258]|29[25]|[46]95|392)|1(?:39[2-6]|59[235])))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
     '505' => '(?:(?:8(?:50[1358]|606)|0392))',
     '506' => '(?:(?:8(?:6(?:66|78|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
     '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24-8]|19[278]|393|492)|5(?:19[23568]|292|494)|2(?:59[2358]|29[235])|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
-    '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-5]|8[058]|1[0-25]|7[57]|2[0258]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
+    '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-5]|8[058]|1[0-25]|7[57]|2[02568]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-68]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
@@ -524,7 +524,7 @@ our %ZIP_TABLE = (
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
     '554' => '(?:85(?:[01]1|8[58]))',
     '555' => '(?:85(?:55|0[12]))',
-    '556' => '(?:8(?:5(?:85|0[13]|5[058]|1[0256])|6(?:01|70|6[03-6])))',
+    '556' => '(?:8(?:5(?:[38]5|0[13]|5[058]|1[0256])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[12]|6[01])|6(?:[01]1|5[18])|729))',
@@ -593,7 +593,7 @@ our %ZIP_TABLE = (
     '627' => '(?:8(?:5(?:55|67|70)|688))',
     '629' => '(?:(?:0(?:19[26-8]|39[28])|2(?:292|498)|1192))',
     '630' => '(?:(?:8(?:5(?:1[028]|3[0356]|2[0289]|8[05-8]|6[367]|7[0578]|0[1-3568]|4[038]|5[0258])|6(?:7[07]|[68][68]|5[15]))|0(?:2(?:88|9[23])|192)|2192))',
-    '631' => '(?:85(?:[58]5|11|2[23]|0[1-35]))',
+    '631' => '(?:85(?:[58]5|11|2[2-4]|0[1-35]))',
     '632' => '(?:(?:8(?:5(?:[14]0|[67]7|8[578]|5[258])|6(?:79|88))|0292))',
     '633' => '(?:(?:8(?:5(?:01|38|85)|686)|0(?:29[28]|39[28])|2[14]92))',
     '634' => '(?:85(?:5[015]|2[1-4]|8[056]|1[01]|6[017]|0[1-35]))',
@@ -747,10 +747,10 @@ our %ZIP_TABLE = (
     '787' => '(?:(?:0[38]92|8501))',
     '788' => '(?:8(?:501|686))',
     '789' => '(?:(?:1(?:[29]92|795)|0392))',
-    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|5[13-7]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|8[013-9]|0[1-3589])|6(?:32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
+    '790' => '(?:8(?:5(?:4[0-356]|7[013-578]|5[13-7]|9[05]|6[015-7]|2[04589]|1[0-4679]|3[0-79]|8[013-9]|0[1-3589])|6(?:01|32|7[78]|6[015-7]|8[68]|5[0-35689])|7(?:87|9[135-8])))',
     '791' => '(?:(?:8(?:5(?:51|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[23578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
     '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
-    '793' => '(?:8(?:5(?:[58]5|0[19]|1[05])|601))',
+    '793' => '(?:8(?:5(?:[58]5|1[056]|0[19])|601))',
     '794' => '(?:(?:8(?:5(?:82|1[018]|0[28])|6(?:1[14]|0[12]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:0[124-8]|1[01])|60[1-3])|0392))',
     '796' => '(?:(?:0(?:29[235]|495|892)|850[12]))',
@@ -767,7 +767,7 @@ our %ZIP_TABLE = (
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
     '808' => '(?:(?:8(?:5(?:1[045]|0[25]|5[058]|8[58])|606)|0196))',
     '809' => '(?:8501)',
-    '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|5[135-8]|2[0-578]|0[1-46-9]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|8[35689]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
+    '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|5[135-8]|2[0-578]|0[1-46-9]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:8[035689]|5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|49[256]|19[23]|39[28]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|1(?:39[2-5]|29[28])|0(?:19[2356]|295)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|[35]\d|0[1-9]|4[0-68]|2[0-24-689]|7[025-8]|6[02689]|1[0-8])|5(?:[23578]\d|1[0-79]|6[0-24-8]|0[1-57-9]|4[0-8])|7(?:0[5-9]|9[24]|1[078]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
@@ -900,7 +900,7 @@ our %ZIP_TABLE = (
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|5[15]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
     '944' => '(?:(?:8(?:5(?:01|88|5[05])|6(?:01|86))|0192))',
-    '945' => '(?:(?:8(?:5(?:[01]1|[38]5|5[58])|6(?:[01]1|88))|1(?:39[3578]|[15]95)|0(?:19[34]|39[57])))',
+    '945' => '(?:(?:8(?:5(?:[01]1|[38]5|5[58])|6(?:[01]1|88))|1(?:39[3578]|[15]95)|0(?:19[2-4]|39[57])))',
     '946' => '(?:(?:8(?:5(?:55|1[13])|601)|0292))',
     '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|765)|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
@@ -918,7 +918,7 @@ our %ZIP_TABLE = (
     '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|1[1258]|8[014589]|5[058]|6[067]|3[0146]|2[0-4])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
-    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|8[569]|7[05-7]|6[014-68]|3[07]|0[129]|1[01])|292|794)|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|0(?:19[25-8]|296)|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
+    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|8[569]|7[05-7]|6[014-68]|3[07]|0[129]|1[01])|292|794)|0(?:19[25-8]|29[67])|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
     '965' => '(?:8(?:5(?:[34]0|67|8[058]|2[02]|0[1-356]|7[07]|5[08]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
